
   /' Utility functions '/
   Declare Function Min(R1 As Single,R2 As Single) As Single
   Declare Function Max(R1 As Single,R2 As Single) As Single
   Declare Function Erf(x As Single) As Single
   Declare Function Erfc(x As Single) As Single
   Declare Function Tanh(x As Single) As Single
   Declare Function Coth(x As Single) As Single
   Declare Function PGauss(Mean As Single,Sigma As Single) As Single
   Declare Function PExp(Tau As Single) As Single
   Declare Function PMaxwell(R_T As Single) As Single
   Declare Function Floor(R As Single) As Single
   Declare Function Log10(R As Single) As Single

   /' Utility functions '/
   Public Function Min(R1 As Single,R2 As Single) As Single
   	Dim Rmin As Single
   	If R1 < R2 Then
   	  Rmin = R1
   	Else
   	  Rmin = R2
   	EndIf
   	Min = Rmin
   End Function

   Public Function Max(R1 As Single,R2 As Single) As Single
   	Dim Rmax As Single
   	If R1 > R2 Then
   	  Rmax = R1
   	Else
   	  Rmax = R2
   	EndIf
   	Max = Rmax
   End Function

   Public Function Erf(x As Single) As Single
     Erf = 1.E0 - Erfc(x)
   End Function

   Public Function Erfc(x As Single) As Single
   /' Complementary error function from numerical recipes '/
     Dim As Single t,z,r
     z = Abs(x)
     t = 1.E0/(1.E0 + 0.5E0 * z)
     r = t*exp(-z*z-1.26551223+t*(1.00002368+t*(0.37409196 _
      +t*(0.09678418+t*(-0.18628806+t*(0.27886807+t*(-1.13520398 _
      +t*(1.48851587+t*(-0.82215223+t*0.17087277)))))))))
     If (x < 0) Then
       Erfc = 2.E0 - r
     Else
       Erfc = r
     Endif
   End Function

   Public Function Tanh(x As Single) As Single
     Dim As Single Result
     Result = (exp(x) - exp(-x)) / (exp(x) + exp(-x))
     Tanh = Result
   End Function

   Public Function Coth(x As Single) As Single
     Dim As Single Result
     Result = (exp(x) + exp(-x)) / (exp(x) - exp(-x))
     Coth = Result
   End Function

Public Function PGauss(Mean As Single,Sigma As Single) as Single
  ' Box-Muller method
  Dim As Integer ISet
  Dim As Single V1,V2,R,Fac,GSet,GasDev,Result
  If ISet = 0 then
    Repeat:
    V1 = 2.E0 * Rnd - 1.E0
    V2 = 2.E0 * Rnd - 1.E0
    R = V1^2 + V2^2
    If R >= 1.E0 Then Goto Repeat
    Fac = Sqr(-2.E0 * Log(R)/R)
    GSet = V1 * Fac
    GasDev = V2 * Fac
    ISet = 1.E0
  Else
    GasDev = GSet
    ISet = 0
  End If
  Result = Sigma * GasDev
  PGauss = Mean + Result
End Function

Public Function PExp(R_Tau as Single) As Single
  /' Random-number generator for an exponential distribution '/
  Dim As Single X1,R_Res
  Again:
  X1 = RND
  If X1 > 1.E-10 And X1 < 0.99999E0 Then
     R_Res = - R_Tau * Log(X1)
  Else
     Goto Again
  End If
  PExp = R_Res
End Function

Public Function PMaxwell(R_T As Single) As Single
   /' Random-number generator for a surface Maxwell distribution '/
   /' y = x * exp(-x/T)  '/
   Dim As Single R_Res
   R_Res = -R_T * (Log(Rnd) + Log(Rnd))
   PMaxwell = R_Res
End Function

Public Function Floor(R As Single) As Single
	Floor = Int(R)
End Function

Public Function Log10(R As Single) As Single
    log10 = Log(R) / Log(10)
End Function
