 Declare Function U_sigtot(Ap As Single, Zp As Single, Ep As Single, _
                           At As Single, Zt As Single) As Single

 Function  U_sigtot(Ap As Single, Zp As Single, Ep As Single, _
                           At As Single, Zt As Single) As Single

   /' Total reaction cross sections '/
  
   Dim As Single ECM,XX,sigtot,D,CE,S,DELTA,RP,RT,RNASA,BNASA,AP13,AT13,EP13,ECM13,_  
              HIM,HIL,SL,TL,RMST,RMSP,RHOP,RHOT,DG,RMS,RC,TP
   Const As Single pi = 3.14159
 

   /' Total reaction cross sections for n- and p-induced reactions
      are calculated according to R.K. Tripathi et al, NIMB 129 (1997) 11 and
      R.K. Tripathi et al, NIMB 117 (1996) 347, with some slight adjustement of
      parameters D for neutrons,  Tl for protons, and adding HIM for protons too.
   '/

   AP13 = AP^(1.E0/3.E0)
   AT13 = AT^(1.E0/3.E0)
   EP13 = EP^(1.E0/3.E0)
   If (ZT < 1.E0) Then RMST = 0.34E0
   If (ZT > 0.E0) Then RMST = 0.85E0
   /' Friedrich & Voegler, NPA373 (1982) 283: '/
   RMSP = 0.891E0*AP13*(1.E0+1.565E0*AP13^(-2)-1.04E0*AP13^(-4))

   RT = 1.29E0*RMST
   RP = 1.29E0*RMSP
   RHOT=AT/(4.E0*PI*RT^3/3.E0)
   RHOP=AP/(4.E0*PI*RP^3/3.E0)

   S = AT13 * AP13 / (AT13 + AP13)
   If(ZT > 0.E0) Then   /' protons '/
     TL = 40.E0  /' Tripathi uses only this factor, for all Ap '/
     IF(Ap >= 120.E0) Then TL = 80.E0    /' This we add to original formula '/
   Else /' neutrons, same as Tripathi '/
     TL = 40.E0
     If (AP >= 11.E0 And AP <= 40.E0) Then TL = 30.E0
   End If

   /' We take for protons and neutrons the same value of D; Tripathi takes for
      protons 2.05 and for neutron somewhat complicated formula. '/
   D = 2.05E0

   ECM = EP * AP / (AT + AP)
   ECM13 = ECM^(1.E0/3.E0)

   If (AP < 200.E0) Then 
     HIL = 2.83E0 - 3.1E-2*AP+1.7E-4*AP^2
     If (AP < 12.E0) Then SL = 0.6E0  
     If (AP = 12.E0) Then SL = 1.6E0
     If (AP > 12.E0) THEN SL = 1.0E0
     HIM = 1.E0 - HIL*exp(-EP/(HIL*SL))
   Else
     HIM = (1.E0-0.3E0*exp(-(EP-1.E0)/15.E0))*(1.E0-exp(0.9E0-EP))
   End if

   RNASA = RP + RT + 1.2E0*(AP13 + AT13) / ECM13 
   BNASA = 1.44E0 * ZT * ZP / RNASA

   CE = D * (1.E0 - exp(-EP/TL)) - 0.292E0*exp(-EP/792.E0) _
                                * cos(0.229E0*EP^0.453E0)

   DELTA = 1.85E0*S + (0.16E0*S/ECM13) - CE + _
                         0.91E0*(AP-2.E0*ZP)*ZT/(AT * AP)

   sigtot = pi * (1.1E0)^2 * (AT13 + AP13 + _
             DELTA)^2 * (1.D0 - BNASA / ECM) * HIM * 10.E0

   If (sigtot < 0.e0) Then sigtot = 0.E0
   If (ECM < BNASA) Then sigtot = 0.E0
   Return sigtot
 End Function
